PyXMake Developer Guide: PyXMake.VTL.stm_make.pylint Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | Static Public Attributes | Protected Member Functions | Static Protected Attributes | List of all members
PyXMake.VTL.stm_make.pylint Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.pylint:

## Public Member Functions
| initialize_options (self)
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)

## Public Attributes
str | command = "pylint"
str | out = "html"
str | output_file_path = "build/pylint.txt"
| verbose = self.distribution.verbose
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose

## Static Public Attributes
str | description = "Runs the pylint command."
list | user_options

## Protected Member Functions
| _create_command (self)
| _perform_post_actions (self)
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _run_command (self, command)

## Static Protected Attributes
str | _PACKAGE_NAME = "src"

## Additional Inherited Members
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()

## Detailed Description

    Runs the pylint command.

Definition at line 930 of file stm_make.py.

## Member Function Documentation

## ◆ _create_command()

PyXMake.VTL.stm_make.pylint._create_command | ( |  | self | ) |
| protected

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 951 of file stm_make.py.

## ◆ _perform_post_actions()

PyXMake.VTL.stm_make.pylint._perform_post_actions | ( |  | self | ) |
| protected

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 956 of file stm_make.py.

## ◆ finalize_options()

PyXMake.VTL.stm_make.pylint.finalize_options | ( |  | self | ) |

Definition at line 946 of file stm_make.py.

## ◆ initialize_options()

PyXMake.VTL.stm_make.pylint.initialize_options | ( |  | self | ) |

Definition at line 941 of file stm_make.py.

## Member Data Documentation

## ◆ _PACKAGE_NAME

PyXMake.VTL.stm_make.pylint._PACKAGE_NAME = "src"
| staticprotected

Definition at line 934 of file stm_make.py.

## ◆ command

PyXMake.VTL.stm_make.pylint.command = "pylint"

Definition at line 942 of file stm_make.py.

## ◆ description

str PyXMake.VTL.stm_make.pylint.description = "Runs the pylint command."
| static

Definition at line 936 of file stm_make.py.

## ◆ out

str PyXMake.VTL.stm_make.pylint.out = "html"

Definition at line 943 of file stm_make.py.

## ◆ output_file_path

PyXMake.VTL.stm_make.pylint.output_file_path = "build/pylint.txt"

Definition at line 944 of file stm_make.py.

## ◆ user_options

list PyXMake.VTL.stm_make.pylint.user_options
| static

Initial value:
= [
("command=", None, "Path and name of the command line tool."),
("out=", None, "Specifies the output type (html, parseable). Default: html")]

Definition at line 937 of file stm_make.py.

## ◆ verbose

PyXMake.VTL.stm_make.pylint.verbose = self.distribution.verbose

Definition at line 947 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py